==> client-3.7.0-sources.jar: com/nexmo/client/sns/request/SnsRequest.java <==
/*
 * Copyright (c) 2011-2017 Nexmo Inc
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.nexmo.client.sns.request;


import java.util.HashMap;
import java.util.Map;


public abstract class SnsRequest {
    private final String command;
    private String to;
    private String topicArn;

    public SnsRequest(final String command,
                      final String to,
                      final String topicArn) {
        this.command = command;
        this.to = to;
        this.topicArn = topicArn;
    }

    public String getCommand() {
        return this.command;
    }

    public Map<String, String> getQueryParameters() {
        Map<String, String> params = new HashMap<String, String>();
        params.put("cmd", getCommand());
        params.put("to", this.to);
        params.put("topic", this.topicArn);
        return params;
    }
}

==> client-5.5.0-sources.jar: com/nexmo/client/sns/request/SnsRequest.java <==
/*
 * Copyright (c) 2011-2017 Nexmo Inc
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.nexmo.client.sns.request;


import java.util.HashMap;
import java.util.Map;


public abstract class SnsRequest {
    private final String command;
    private String to;
    private String topicArn;

    public SnsRequest(final String command,
                      final String to,
                      final String topicArn) {
        this.command = command;
        this.to = to;
        this.topicArn = topicArn;
    }

    public String getCommand() {
        return this.command;
    }

    public Map<String, String> getQueryParameters() {
        Map<String, String> params = new HashMap<>();
        params.put("cmd", getCommand());
        params.put("to", this.to);
        params.put("topic", this.topicArn);
        return params;
    }
}
